@@ -70,13 +70,13 @@ def lnprobmodel(model, data):
         model = (model * sed_factor).to(data['flux'].unit)
 
     ul = data['ul']
-    notul = -ul
+    notul = ~ul
 
     difference = model[notul] - data['flux'][notul]
 
     # use different errors for model above or below data
     sign = difference > 0
-    loerr, hierr = 1 * -sign, 1 * sign
+    loerr, hierr = 1 * ~sign, 1 * sign
     logprob = -difference**2 / (2. * (loerr * data['flux_error_lo'][notul] +
                                       hierr * data['flux_error_hi'][notul])**2)
 
