@@ -305,10 +305,12 @@ class Synchrotron(BaseElectron):
             AKP10 Eq. D7
 
             Factor ~2 performance gain in using cbrt(x)**n vs x**(n/3.)
+            Invoking crbt only once reduced time by ~40%
             """
-            gt1 = 1.808 * cbrt(x) / np.sqrt(1 + 3.4 * cbrt(x)**2.)
-            gt2 = 1 + 2.210 * cbrt(x)**2. + 0.347 * cbrt(x)**4.
-            gt3 = 1 + 1.353 * cbrt(x)**2. + 0.217 * cbrt(x)**4.
+            cb = cbrt(x)
+            gt1 = 1.808 * cb / np.sqrt(1 + 3.4 * cb**2.)
+            gt2 = 1 + 2.210 * cb**2. + 0.347 * cb**4.
+            gt3 = 1 + 1.353 * cb**2. + 0.217 * cb**4.
             return gt1 * (gt2 / gt3) * np.exp(-x)
 
         log.debug('calc_sy: Starting synchrotron computation with AKB2010...')
@@ -1087,7 +1089,6 @@ class PionDecay(BaseProton):
     123014 <http://adsabs.harvard.edu/abs/2014PhRvD..90l3014K>`_.
 
 
-
     Parameters
     ----------
     particle_distribution : function
@@ -1651,7 +1652,7 @@ class PionDecayKelner06(BaseRadiative):
         qpi = (self._c *
                (self.nhat / self._Kpi) * self._sigma_inel(Ep0) *
                self._particle_distribution(Ep0))
-        return qpi / np.sqrt(Epi**2 + self._m_pi**2)
+        return qpi / np.sqrt(Epi**2 - self._m_pi**2)
 
     def _calc_specpp_loE(self, Egamma):
         """
